grymp
=====

.. image:: https://travis-ci.org/gebn/grymp.svg?branch=master
   :target: https://travis-ci.org/gebn/grymp
.. image:: https://coveralls.io/repos/github/gebn/grymp/badge.svg?branch=master
   :target: https://coveralls.io/github/gebn/grymp?branch=master
.. image:: https://landscape.io/github/gebn/grymp/master/landscape.svg?style=flat
   :target: https://landscape.io/github/gebn/grymp/master
